[−][src]Struct msql_srv::Column
Meta-information abot a single column, used either to describe a prepared statement parameter or an output column.
Fields
table: StringThis column's associated table.
Note that this is technically the table's alias.
column: StringThis column's name.
Note that this is technically the column's alias.
coltype: ColumnTypeThis column's type>
colflags: ColumnFlagsAny flags associated with this column.
Of particular interest are ColumnFlags::UNSIGNED_FLAG and ColumnFlags::NOT_NULL_FLAG.