[−][src]Struct msql_srv::StatementMetaWriter
Convenience type for responding to a client PREPARE command.
This type should not be dropped without calling
reply or
error.
Methods
impl<'a, W: Write + 'a> StatementMetaWriter<'a, W>[src]
pub fn reply<PI, CI>(self, id: u32, params: PI, columns: CI) -> Result<()> where
PI: IntoIterator<Item = &'a Column>,
CI: IntoIterator<Item = &'a Column>,
<PI as IntoIterator>::IntoIter: ExactSizeIterator,
<CI as IntoIterator>::IntoIter: ExactSizeIterator, [src]
PI: IntoIterator<Item = &'a Column>,
CI: IntoIterator<Item = &'a Column>,
<PI as IntoIterator>::IntoIter: ExactSizeIterator,
<CI as IntoIterator>::IntoIter: ExactSizeIterator,
Reply to the client with the given meta-information.
id is a statement identifier that the client should supply when it later wants to execute
this statement. params is a set of Column descriptors for the
parameters the client must provide when executing the prepared statement. columns is a
second set of Column descriptors for the values that will be
returned in each row then the statement is later executed.
pub fn error<E: ?Sized>(self, kind: ErrorKind, msg: &E) -> Result<()> where
E: Borrow<[u8]>, [src]
E: Borrow<[u8]>,
Reply to the client's PREPARE with an error.