[][src]Struct msql_srv::Value

pub struct Value<'a>(_);

MySQL value as provided when executing prepared statements.

Methods

impl<'a> Value<'a>[src]

pub fn into_inner(self) -> ValueInner<'a>[src]

Return the inner stored representation of this value.

This may be useful for when you do not care about the exact data type used for a column, but instead wish to introspect a value you are given at runtime. Note that the contained value may be stored in a type that is more general than what the corresponding parameter type allows (e.g., a u8 will be stored as an u64).

pub fn is_null(&self) -> bool[src]

Returns true if this is a NULL value