[−]Struct msql_srv::ColumnFlags
MySql column flags
Methods
impl ColumnFlags
pub const NOT_NULL_FLAG: ColumnFlags
Field can't be NULL.
pub const PRI_KEY_FLAG: ColumnFlags
Field is part of a primary key.
pub const UNIQUE_KEY_FLAG: ColumnFlags
Field is part of a unique key.
pub const MULTIPLE_KEY_FLAG: ColumnFlags
Field is part of a key.
pub const BLOB_FLAG: ColumnFlags
Field is a blob.
pub const UNSIGNED_FLAG: ColumnFlags
Field is unsigned.
pub const ZEROFILL_FLAG: ColumnFlags
Field is zerofill.
pub const BINARY_FLAG: ColumnFlags
Field is binary.
pub const ENUM_FLAG: ColumnFlags
Field is an enum.
pub const AUTO_INCREMENT_FLAG: ColumnFlags
Field is a autoincrement field.
pub const TIMESTAMP_FLAG: ColumnFlags
Field is a timestamp.
pub const SET_FLAG: ColumnFlags
Field is a set.
pub const NO_DEFAULT_VALUE_FLAG: ColumnFlags
Field doesn't have default value.
pub const ON_UPDATE_NOW_FLAG: ColumnFlags
Field is set to NOW on UPDATE.
pub const PART_KEY_FLAG: ColumnFlags
Intern; Part of some key.
pub const NUM_FLAG: ColumnFlags
Field is num (for clients).
pub fn empty() -> ColumnFlags
Returns an empty set of flags.
pub fn all() -> ColumnFlags
Returns the set containing all flags.
pub fn bits(&self) -> u16
Returns the raw value of the flags currently stored.
pub fn from_bits(bits: u16) -> Option<ColumnFlags>
Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
pub fn from_bits_truncate(bits: u16) -> ColumnFlags
Convert from underlying bit representation, dropping any bits that do not correspond to flags.
pub fn is_empty(&self) -> bool
Returns true if no flags are currently stored.
pub fn is_all(&self) -> bool
Returns true if all flags are currently set.
pub fn intersects(&self, other: ColumnFlags) -> bool
Returns true if there are flags common to both self and other.
pub fn contains(&self, other: ColumnFlags) -> bool
Returns true all of the flags in other are contained within self.
pub fn insert(&mut self, other: ColumnFlags)
Inserts the specified flags in-place.
pub fn remove(&mut self, other: ColumnFlags)
Removes the specified flags in-place.
pub fn toggle(&mut self, other: ColumnFlags)
Toggles the specified flags in-place.
pub fn set(&mut self, other: ColumnFlags, value: bool)
Inserts or removes the specified flags depending on the passed value.